@@ -225,7 +225,7 @@ setTaffybarSize cfg window = do
   nmonitors <- screenGetNMonitors screen
   allMonitorSizes <- mapM (screenGetMonitorGeometry screen) [0 .. (nmonitors - 1)]
 
-  when (monitorNumber cfg < nmonitors) $ do
+  when (monitorNumber cfg >= nmonitors) $ do
     IO.hPutStrLn IO.stderr $ printf "Monitor %d is not available in the selected screen" (monitorNumber cfg)
 
   let monitorSize = fromMaybe (allMonitorSizes !! 0) $ do
@@ -261,16 +261,15 @@ setTaffybarSize cfg window = do
 
 taffybarMain :: TaffybarConfig -> IO ()
 taffybarMain cfg = do
-  -- Override the default GTK theme path settings.  This causes the
-  -- bar (by design) to ignore the real GTK theme and just use the
-  -- provided minimal theme to set the background and text colors.
-  -- Users can override this default.
-  defaultGtkConfig <- getDefaultConfigFile "taffybar.rc"
-  userGtkConfig <- getUserConfigFile "taffybar" "taffybar.rc"
-  rcSetDefaultFiles [ defaultGtkConfig, userGtkConfig ]
 
   _ <- initGUI
 
+  -- Load default and user gtk resources
+  defaultGtkConfig <- getDefaultConfigFile "taffybar.rc"
+  userGtkConfig <- getUserConfigFile "taffybar" "taffybar.rc"
+  rcParse defaultGtkConfig
+  rcParse userGtkConfig
+
   Just disp <- displayGetDefault
   nscreens <- displayGetNScreens disp
   screen <- case screenNumber cfg < nscreens of
